#
# spec file for package nlopt
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global flavor %{nil}

%if "%{flavor}" == ""
%bcond_without bindings
%endif
%if "%{flavor}" == "main"
%bcond_with   bindings
%define psuffix -main
%endif
%define pname nlopt
%define so_ver 1

Name:           nlopt%{?psuffix}
Version:        2.10.0
Release:        1.2
Summary:        A library for nonlinear optimization
License:        LGPL-2.1-or-later
URL:            https://nlopt.readthedocs.io/en/latest/
Source0:        https://github.com/stevengj/nlopt/archive/v%{version}.tar.gz#/%{pname}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  hdf5-devel
BuildRequires:  pkgconfig
%if %{with bindings}
BuildRequires:  %{python_module numpy-devel}
BuildRequires:  java-devel > 11
BuildRequires:  strip-nondeterminism
BuildRequires:  swig
BuildRequires:  pkgconfig(octave)
Requires:       python-numpy
%python_subpackages
%endif

%description
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package     -n lib%{pname}%{so_ver}
Summary:        A library for nonlinear optimization

%description -n lib%{pname}%{so_ver}
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

%package -n     %{pname}-devel
Summary:        Development files for %{pname}
Requires:       lib%{pname}%{so_ver} = %{version}

%description -n %{pname}-devel
The %{pname}-devel package contains libraries and header files for
developing applications that use NLopt.

%if %{with bindings}
%package     -n octave-nlopt_optimize
Summary:        Octave interface to nonlinear optimization library
%requires_eq    octave-cli

%description -n octave-nlopt_optimize
NLopt is a free/open-source library for nonlinear optimization,
providing a common interface for a number of different free
optimization routines available online as well as original
implementations of various other algorithms.

This package contains the Octave interface for NLopt.
%endif

%package -n %{pname}-java
Summary:        Java bindings for NLopt
BuildArch:      noarch

%description -n %{pname}-java
This package provides java bindings for NLopt, a nonlinear optimization
library.

%prep
%autosetup -p1 -n %{pname}-%{version}

%build
# Must be built with -D_FORTIFY_SOURCE=2 (not 3) for tests to pass, see <https://github.com/stevengj/nlopt/issues/563>
%if %{with bindings}
%{python_expand # Necessary to run configure with all python flavors
export PYTHON=$python
mkdir ../${PYTHON}_build
cp -pr ./ ../${PYTHON}_build
pushd ../${PYTHON}_build
%cmake \
   -DCMAKE_C_FLAGS="%(echo %optflags | sed 's/-D_FORTIFY_SOURCE=3/-D_FORTIFY_SOURCE=2/g')" \
   -DCMAKE_CXX_FLAGS="%(echo %optflags | sed 's/-D_FORTIFY_SOURCE=3/-D_FORTIFY_SOURCE=2/g')" \
   -DCMAKE_SKIP_RPATH:BOOL=OFF \
   -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
   -DNLOPT_MATLAB=OFF \
   -DNLOPT_CXX:BOOL=ON \
   -DNLOPT_TESTS:BOOL=ON \
   -DNLOPT_PYTHON:BOOL=ON \
   -DNLOPT_OCTAVE:BOOL=ON \
   -DNLOPT_SWIG:BOOL=ON \
   -DNLOPT_JAVA:BOOL=ON \
   -DPython_EXECUTABLE=%{_bindir}/$python \
   %{nil}
%cmake_build
popd
}
%else
%cmake \
   -DCMAKE_C_FLAGS="%(echo %optflags | sed 's/-D_FORTIFY_SOURCE=3/-D_FORTIFY_SOURCE=2/g')" \
   -DCMAKE_CXX_FLAGS="%(echo %optflags | sed 's/-D_FORTIFY_SOURCE=3/-D_FORTIFY_SOURCE=2/g')" \
   -DCMAKE_SKIP_RPATH:BOOL=OFF \
   -DCMAKE_SKIP_INSTALL_RPATH:BOOL=ON \
   -DNLOPT_MATLAB=OFF \
   -DNLOPT_CXX:BOOL=ON \
   -DNLOPT_TESTS:BOOL=ON \
   -DNLOPT_PYTHON:BOOL=OFF \
   -DNLOPT_OCTAVE:BOOL=OFF \
   -DNLOPT_SWIG:BOOL=OFF \
   %{nil}
%cmake_build
%endif

%install
%if %{with bindings}
%{python_expand # Necessary to run configure with all python flavors
export PYTHON=$python
pushd ../${PYTHON}_build
%cmake_install
# remove files from the main package
for e in %{_includedir} %{_libdir}/lib\* %{_libdir}/pkgconfig %{_libdir}/cmake %{_mandir} ; do
    rm -R %{buildroot}/${e}
done
strip-all-nondeterminism %{buildroot}%{_datadir}/java/%{pname}.jar
%fdupes %{buildroot}%{$python_sitearch}
popd
}
%else
%cmake_install
%endif

%check
%if %{with bindings}
%{python_expand # Necessary to run configure with all python flavors
export PYTHON=$python
pushd ../${PYTHON}_build
%ctest
}
%else
%ctest
%endif

%if "%{flavor}" == "main"

%ldconfig_scriptlets -n lib%{pname}%{so_ver}

%files -n lib%{pname}%{so_ver}
%{_libdir}/*.so.*

%files -n %{pname}-devel
%license COPYING
%doc AUTHORS NEWS.md README.md TODO
%{_includedir}/*
%{_libdir}/*.so
%{_libdir}/pkgconfig/%{pname}.pc
%{_libdir}/cmake/%{pname}/
%{_mandir}/man3/*.3%{?ext_man}
%endif

%if %{with bindings}
%files %{python_files}
%license COPYING
%{python_sitearch}/nlopt-%{version}*.*-info/
%{python_sitearch}/nlopt.py
%{python_sitearch}/*.so

%files -n octave-nlopt_optimize
%license COPYING
%dir %{_libdir}/octave/*/site
%dir %{_libdir}/octave/*/site/oct
%dir %{_libdir}/octave/*/site/oct/*
%{_libdir}/octave/*/site/oct/*/*.oct
%{_datadir}/octave/*/site/m/*

%files -n %{pname}-java
%license COPYING
%{_datadir}/java/%{pname}.jar
%endif

%changelog
* Sun Feb  9 2025 Bernhard Wiedemann <bwiedemann@suse.com>
- Use strip-nondeterminism to normalize jar mtimes for reproducible builds
* Thu Feb  6 2025 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.10.0:
  * New Java bindings (gh#stevengj/nlopt#578).
  * Allow disabling exceptions with set_exceptions_enabled
    (gh#stevengj/nlopt#580).
  * Configurable tolg tolerance parameter for Luksan gradient
    stopping condition (gh#stevengj/nlopt#585).
  * Restored LD_LBFGS_NOCEDAL enum value (dropped in 2.9) to ease
    backwards compatibility for wrappers in other languages
    (though this algorithm is currently unimplemented)
    (gh#stevengj/nlopt#587).
- Build and install java bindings as part of a newly split
  nlopt-java package.
- Bump shlib name in keeping with upstream so version update.
* Fri Dec 20 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.9.1:
  * Fixed PRAXIS box constraints (gh#stevengj/nlopt#528).
* Sun Nov 17 2024 Atri Bhattacharya <badshah400@gmail.com>
- Fix %%requires_eq usage for "pkgconfig(octave)".
* Thu Nov 14 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.9.0:
  * New NLOPT_LUKSAN cmake option to build without Luksan LGPL
    code (gh#stevengj/nlopt#568).
  * Dropped unused LD_LBFGS_NOCEDAL enum value.
  * Python 3.13 support (gh#stevengj/nlopt#565).
  * Fixed COBYLA not returning the optimum (gh#stevengj/nlopt#57)
  * Fixed SLSQP returning infeasible optimum
    (gh#stevengj/nlopt#368)
  * Fixed STOGO not registering new optimum
    (gh#stevengj/nlopt#504)
  * Various minor bugfixes (gh#stevengj/nlopt#570,
    gh#stevengj/nlopt#563, gh#stevengj/nlopt#379,
    gh#stevengj/nlopt#511)
- Update License to LGPL-2.1-or-later in keeping with upstream.
* Sat Aug 10 2024 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.8.0:
  * Support C++ functors for objective functions
    (gh#stevengj/nlopt#457).
  * CCSA/MMA an now use the initial_step parameter to bound their
    initial stepsize,
  * and also expose a new internal parameter rho_init
    (gh#stevengj/nlopt#561).
  * Install pkg-config file on Windows (gh#stevengj/nlopt#534).
  * Allow having more equality constraints than there are
    variables (gh#stevengj/nlopt#509).
  * Bugfixes:
  - gh#stevengj/nlopt#558
  - gh#stevengj/nlopt#533
  - gh#stevengj/nlopt#473
  - gh#stevengj/nlopt#465
  * Build improvements (gh#stevengj/nlopt#551,
    gh#stevengj/nlopt#535, gh#stevengj/nlopt#510,
    gh#stevengj/nlopt#445).
- Build with -D_FORTIFY_SOURCE=2 (not 3) to avoid test crashes
  (gh#stevengj/nlopt#563).
* Fri Feb 11 2022 Atri Bhattacharya <badshah400@gmail.com>
- Build for all supported python flavours.
- Edit flavor names so that auto-generated python packages are
  called pythonXY-nlopt and not pythonXY-nlopt-bindings; no-name
  flavor now builds the bindings, while "main" flavor builds the
  main C/C++ library and devel package.
* Tue Feb  8 2022 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Split bindings into separate build, to avoid the octave (and
  thus Java, Qt5, ...) dependency. Also allows to build the
  library on SLE 15.x.
- Adjust Python3 package name (python-nlopt -> python3-nlopt)
* Tue Dec  7 2021 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.7.1:
  * Various minor bugfixes (gh#stevengj/nlopt#268,
    gh#stevengj/nlopt#409, gh#stevengj/nlopt#420)
  * Build improvements (support Octave 6.x, Guile 3.x, Cmake 3.2).
* Sun Nov 29 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.7.0:
  * New nlopt_set_param API for setting internal algorithm
    parameters (gh#stevengj/nlopt#365).
  * Avoid library-symbol conflicts (gh#stevengj/nlopt#355,
    gh#stevengj/nlopt#361)
- Run tests using ctest as part of %%check section.
- Handle erroneous RPATH in openSUSE:Leap:15.2's %%cmake macro by
  explicitly setting CMAKE_SKIP_RPATH to OFF and
  CMAKE_SKIP_INSTALL_RPATH to ON; while only required for 15.2,
  setting these for all versions doesn't hurt.
* Sun Apr 26 2020 Atri Bhattacharya <badshah400@gmail.com>
- Update to verion 2.6.2:
  * Fixed forced stop exception with dimension elimination
    (gh#stevengj/nlopt#317).
  * Fixed get_initial_step wrapping (gh#stevengj/nlopt#319).
  * Various build fixes (gh#stevengj/nlopt#314,
    gh#stevengj/nlopt#308, gh#stevengj/nlopt#303,
    gh#stevengj/nlopt#278).
- Rename source tarball into %%{name}-%%{version} format.
* Mon Apr 15 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.6.1:
  * Fix nlopt_version return value for 2.6.x and update soname and
    docs.
- Changes from version 2.6.0:
  * New set_upper_bound and set_lower_bound functions in the
    low-level C API to set one bound at a time
    (gh#stevengj/nlopt#257).
  * There is no longer a separate libnlopt_cxx library — C++
    algorithms (stogo) are compiled and included by default
    (gh#stevengj/nlopt#198).
  * Bug fixes:
  * gh#stevengj/nlopt#197
  * gh#stevengj/nlopt#216
  * gh#stevengj/nlopt#245
  * gh#stevengj/nlopt#250
  * gh#stevengj/nlopt#230
  * gh#stevengj/nlopt#261
  * gh#stevengj/nlopt#242
  * gh#stevengj/nlopt#258.
- Drop patches incorporated upstream:
  * nlopt-octave-5.0.patch
  * nlopt-cmake-3.13.patch.
* Sat Mar 30 2019 Atri Bhattacharya <badshah400@gmail.com>
- Update to version 2.5.0:
  * New AGS global solver (gh#stevengj/nlopt#194).
  * New `nlopt_get_numevals` function providing a built-in
    evaluation counter (gh#stevengj/nlopt#160).
  * New `nlopt_get_errmsg` function for more descriptive error
    messages.
  * Build system is converted to `cmake` (gh#stevengj/nlopt#49).
  * Plugins updated for recent Octave and Guile versions.
  * Various other build fixes and minor bug fixes.
- Drop patches already incorporated upstream or otherwise fixed:
  * nlopt-2.3-pkgconfig.patch
  * pythondir.patch
  * nlopt-octave-4.0.patch
  * nlopt-octave4.4-prefixdir.patch
  * nlopt-octave4.4-do_multi_index_op.patch
- New patches:
  * nlopt-octave-5.0.patch: Fix compilation and running against
    octave >= 5.0; patch taken from upstream git commit.
  * nlopt-cmake-3.13.patch: Fix building python module when using
    cmake 3.13+; patch taken from upstream git commit and rebased
    to apply cleanly.
- Switch to building python3 modules instead of python2.
- Switch to cmake build system in keeping with upstream; introduce
  BuildRequires: cmake and drop libtool.
- New BuildRequires: swig needed to build python module.
- Use %%%%autosetup to setup build directory and apply patches.
* Sat Jun  2 2018 badshah400@gmail.com
- Add patches to fix compilation against octave 4.4:
  * nlopt-octave4.4-prefixdir.patch: Fix how to find octave's
    prefix dir in configure.ac: octave-config no longer supports
    the keyword PREFIX and uses OCTAVE_HOME in its stead; patch
    being sent upstream. Add BuildRequires: libtool and regenerate
    build files (autoreconf -fvi) before configuring build.
  * nlopt-octave4.4-do_multi_index_op.patch: Replace
    do_multi_index_op by feval; the former is dropped from octave
    4.4; patch being sent upstream.
- Package python modules installed to sitelib as well.
* Thu Jun 23 2016 badshah400@gmail.com
- Use %%requires_eq octave-cli instead of Requires, octave installs
  its files to versioned dirs, so it is important for nlopt to
  be rebuilt for every version update of octave. Making the
  Requires version dependent achieves this.
* Tue Nov 17 2015 dmitry_r@opensuse.org
- Fix compatibility with Octave 4.0
  * nlopt-octave-4.0.patch
* Sun May 31 2015 dmitry_r@opensuse.org
- Disable Octave module due to incompatibility with Octave 4.0
* Thu Nov 13 2014 dmitry_r@opensuse.org
- Update to version 2.4.2
  * Bugfix release, see included NEWS file for details.
- Update package descriptionts.
* Tue Feb 11 2014 badshah400@gmail.com
- Update to version 2.4.1
  - No Linux relevant changes from version 2.4.0
- Changes from version 2.4.0:
  + New genetic algorithm ESCH
  + Fix swig dir for VPATH builds
  + Use python-config program in the configure script to find the
    include directories for Python, if possible (may be overridden
    by PYTHON_CONFIG environment variable)
  + Bugfix in copy constructor for C++ and Python interfaces
  + Bugfix in return value for setting min/max objective
  + Handle negative rescalings in COBYLA and BOBYQA
  + Plugin installation honors the configure --prefix, if any
  + Various compilation fixes for compatibility with recent
    software
- Packaging changes:
  + Minor rebase of pythondir.patch
  + Drop nlopt-2.3-no-return-in-nonvoid-function.patch: corrected
    upstream.
* Tue Sep 10 2013 dvaleev@suse.com
- install python parts to sitearch (pythondir.patch)
* Wed Jun 12 2013 tchvatal@suse.com
- Add fix for .pc file so we can use this library even
  with other projects.
  * nlopt-2.3-pkgconfig.patch
* Sun Feb 24 2013 scorot@free.fr
- remove %%%%clean section
- add minimal single-line comment in spec file for patch0
- add files on %%%%doc section
- spec file cleanup
- add python(abi) requirements recent recent products
- update source url
* Sun Aug 19 2012 scorot@free.fr
- again fix build on x86_64
* Sun Aug 19 2012 scorot@free.fr
- fix build on x86_64
- fix package group names
* Sun Aug 19 2012 scorot@free.fr
- first package
